@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudformation._jsii
 import aws_cdk.aws_codebuild._jsii
@@ -20,7 +20,7 @@ import aws_cdk.cx_api._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/app-delivery", "1.63.0", __name__[0:-6], "app-delivery@1.63.0.jsii.tgz"
+    "@aws-cdk/app-delivery", "1.66.0", __name__[0:-6], "app-delivery@1.66.0.jsii.tgz"
 )
 
 __all__ = [
